@@ -7,16 +7,15 @@ from __future__ import unicode_literals
 import os
 import django.utils.translation.trans_real
 from . import parser
-from .file_watcher import FileWatcher
 
 
-class TranslationsLoader(FileWatcher):
-    def __init__(self, locales, locale_paths):
-        self.locales = locales
+class TranslationsLoader(object):
+    def __init__(self, locale_paths=(), locales=()):
         self.locale_paths = locale_paths
+        self.locales = locales
         super(TranslationsLoader, self).__init__()
 
-    def do_load(self):
+    def execute(self):
         for locale in self.locales:
             language = django.utils.translation.trans_real.to_language(locale)
             # XXX: this will trigger useless loading of translations from django code
@@ -27,11 +26,11 @@ class TranslationsLoader(FileWatcher):
 
     def list_files(self):
         for locale in self.locales:
-            for file_path in self._get_translation_files(locale, include_missing=True):
+            for file_path in self._get_translation_files(locale):
                 yield file_path
 
-    def _get_translation_files(self, locale, include_missing=False):
+    def _get_translation_files(self, locale):
         for locale_path in self.locale_paths:
             translation_path = os.path.join(locale_path, locale, 'LC_MESSAGES/django.po')
-            if include_missing or os.path.isfile(translation_path):
+            if os.path.isfile(translation_path):
                 yield translation_path
